# Selenium Library Extends

With the extension of the selenium library, we can meet the needs of our customers and the community by bringing more accuracy in the way of using these keywords which we are adapting to the BDD and thus making the writing more readable and making the learning curve easier.

[![Commitizen friendly](https://img.shields.io/badge/commitizen-friendly-brightgreen.svg)](http://commitizen.github.io/cz-cli/)

## Join the DBSPT Community and Spread the Word

⚡️ [Join the Discussion forum on GitHub](https://github.com/dbspt/SeleniumLibraryExtends/discussions) 📣

⚡️ Leave a GitHub star ⭐️ 👆

⚡️ Spread the word on your socials and with your networks! 🗣

## Contribute

For a complete guide to contributing to Selenium Library Extends, see the [Contribution Guide](CONTRIBUTING.md).

1.  Fork this repo
2.  Create your feature branch: git checkout -b feature-name
3.  Commit your changes: git commit -am 'Add some feature'
4.  Push to the branch: git push origin my-new-feature
5.  Submit a pull request

## License

[MIT](https://opensource.org/licenses/MIT) 🕊